@@ -85,7 +85,7 @@ def explodeDn(dn, notypes=0):
     return ldap.dn.explode_dn(dn, notypes)
 
 
-def getRootDnConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
+def getRootDnConnection(start_tls=None, decode_ignorelist=[], reconnect=True):
     # type: (int, List[str], bool) -> access
     """
     Open a LDAP connection to the local LDAP server with the LDAP root account.
@@ -110,7 +110,7 @@ def getRootDnConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
     return access(host=host, port=port, base=ucr['ldap/base'], binddn=binddn, bindpw=bindpw, start_tls=start_tls, decode_ignorelist=decode_ignorelist, reconnect=reconnect)
 
 
-def getAdminConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
+def getAdminConnection(start_tls=None, decode_ignorelist=[], reconnect=True):
     # type: (int, List[str], bool) -> access
     """
     Open a LDAP connection to the Primary Directory Node LDAP server using the admin credentials.
@@ -129,7 +129,7 @@ def getAdminConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
     return access(host=ucr['ldap/master'], port=port, base=ucr['ldap/base'], binddn='cn=admin,' + ucr['ldap/base'], bindpw=bindpw, start_tls=start_tls, decode_ignorelist=decode_ignorelist, reconnect=reconnect)
 
 
-def getBackupConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
+def getBackupConnection(start_tls=None, decode_ignorelist=[], reconnect=True):
     # type: (int, List[str], bool) -> access
     """
     Open a LDAP connection to a Backup Directory Node LDAP server using the admin credentials.
@@ -154,7 +154,7 @@ def getBackupConnection(start_tls=2, decode_ignorelist=[], reconnect=True):
         return access(host=backup, port=port, base=ucr['ldap/base'], binddn='cn=backup,' + ucr['ldap/base'], bindpw=bindpw, start_tls=start_tls, decode_ignorelist=decode_ignorelist, reconnect=reconnect)
 
 
-def getMachineConnection(start_tls=2, decode_ignorelist=[], ldap_master=True, secret_file="/etc/machine.secret", reconnect=True, random_server=False):
+def getMachineConnection(start_tls=None, decode_ignorelist=[], ldap_master=True, secret_file="/etc/machine.secret", reconnect=True, random_server=False):
     # type: (int, List[str], bool, str, bool, bool) -> access
     """
     Open a LDAP connection using the machine credentials.
@@ -243,7 +243,7 @@ class access(object):
     :param bool reconnect: Automatically re-establish connection to LDAP server if connection breaks.
     """
 
-    def __init__(self, host='localhost', port=None, base='', binddn='', bindpw='', start_tls=2, ca_certfile=None, decode_ignorelist=[], use_ldaps=False, uri=None, follow_referral=False, reconnect=True):
+    def __init__(self, host='localhost', port=None, base='', binddn='', bindpw='', start_tls=None, ca_certfile=None, decode_ignorelist=[], use_ldaps=False, uri=None, follow_referral=False, reconnect=True):
         # type: (str, int, str, Optional[str], str, int, str, List, bool, str, bool, bool) -> None
         self.host = host
         self.base = base
@@ -262,6 +262,9 @@ class access(object):
         ucr = ConfigRegistry()
         ucr.load()
 
+        if self.start_tls is None:
+            self.start_tls = ucr.get_int('directory/manager/starttls', 2)
+
         if not self.port:  # if no explicit port is given
             self.port = int(ucr.get('ldap/server/port', 7389))  # take UCR value
             if use_ldaps and self.port == 7389:  # adjust the standard port for ssl
@@ -552,7 +555,7 @@ class access(object):
     def __search(self, *args, **kwargs):
         response = kwargs.pop('response', None)
         if isinstance(response, dict) and kwargs.get('serverctrls'):
-            rtype, res, rmsgid, resp_ctrls = self.lo.result3(self.lo.search_ext(*args, **kwargs))
+            _rtype, res, _rmsgid, resp_ctrls = self.lo.result3(self.lo.search_ext(*args, **kwargs))
             response['ctrls'] = resp_ctrls
             return res
         else:
@@ -726,12 +729,12 @@ class access(object):
         nal = self.__encode_entry([(k, list(v)) for k, v in nal.items()])
 
         try:
-            rtype, rdata, rmsgid, resp_ctrls = self.lo.add_ext_s(dn, nal, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = self.lo.add_ext_s(dn, nal, serverctrls=serverctrls)
         except ldap.REFERRAL as exc:
             if not self.follow_referral:
                 raise
             lo_ref = self._handle_referral(exc)
-            rtype, rdata, rmsgid, resp_ctrls = lo_ref.add_ext_s(dn, nal, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = lo_ref.add_ext_s(dn, nal, serverctrls=serverctrls)
 
         if serverctrls and isinstance(response, dict):
             response['ctrls'] = resp_ctrls
@@ -846,12 +849,12 @@ class access(object):
             serverctrls = []
 
         try:
-            rtype, rdata, rmsgid, resp_ctrls = self.lo.modify_ext_s(dn, ml, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = self.lo.modify_ext_s(dn, ml, serverctrls=serverctrls)
         except ldap.REFERRAL as exc:
             if not self.follow_referral:
                 raise
             lo_ref = self._handle_referral(exc)
-            rtype, rdata, rmsgid, resp_ctrls = lo_ref.modify_ext_s(dn, ml, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = lo_ref.modify_ext_s(dn, ml, serverctrls=serverctrls)
 
         if serverctrls and isinstance(response, dict):
             response['ctrls'] = resp_ctrls
@@ -899,12 +902,12 @@ class access(object):
             serverctrls = []
 
         try:
-            rtype, rdata, rmsgid, resp_ctrls = self.lo.rename_s(dn, newrdn, newsuperior, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = self.lo.rename_s(dn, newrdn, newsuperior, serverctrls=serverctrls)
         except ldap.REFERRAL as exc:
             if not self.follow_referral:
                 raise
             lo_ref = self._handle_referral(exc)
-            rtype, rdata, rmsgid, resp_ctrls = lo_ref.rename_s(dn, newrdn, newsuperior, serverctrls=serverctrls)
+            _rtype, _rdata, _rmsgid, resp_ctrls = lo_ref.rename_s(dn, newrdn, newsuperior, serverctrls=serverctrls)
 
         if serverctrls and isinstance(response, dict):
             response['ctrls'] = resp_ctrls
